!
! THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
! IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
! THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
! (AT YOUR OPTION) ANY LATER VERSION.
!
! THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
! BUT WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
! MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  SEE THE
! GNU GENERAL PUBLIC LICENSE FOR MORE DETAILS.
!
! YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
! ALONG WITH THIS PROGRAM; IF NOT, SEE <HTTP://WWW.GNU.ORG/LICENSES/>.
!
! Copyright (C) Martin Koehler, 2017-2023
!

!> @brief Initialize MEPACK from Fortran
!>
!> The MEPACK_INITIALIZE subroutine initializes MEPACK if it is called from
!> Fortran. The routine initializes the machine specific parameters and
!> read the environment variables. If a user defined tuning file is provided
!> this file is loaded. Otherwise the builtin tuning file is loaded.
!>
!> @see mepack_init
!> @ingroup auxinit
SUBROUTINE MEPACK_INITIALIZE()
    USE MEPACK_OPTIONS_MACHINE_DOUBLE
    USE MEPACK_OPTIONS_MACHINE_SINGLE
    USE MEPACK_OPTIONS_VERBOSE
    IMPLICIT NONE

    EXTERNAL MEPACK_LUA_INIT
    INTEGER :: INFO

    CALL MEPACK_OPTIONS_MACHINE_DOUBLE_INIT()
    CALL MEPACK_OPTIONS_MACHINE_SINGLE_INIT()

    CALL VERBOSE_INIT()
    CALL MEPACK_LUA_INIT(INFO)
    RETURN
END SUBROUTINE MEPACK_INITIALIZE
